@@ -149,7 +149,8 @@ class BaseHierarcy(Model):
         item = parent
         name = f'/{item.name}{name}'
         if item.parent:
-            return self.get_parent_name(item.parent, name)
+            parent = self.get_parent_name(item.parent, name)
+            return parent
         return name
 
     def get_root(self, parent):
